from starlite.middleware.compression.base import CompressionMiddleware

__all__ = ("CompressionMiddleware",)
